==> jc-1.4.0.tar.gz: javax/swing/plaf/BorderUIResource__24CompoundBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$CompoundBorderUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 1ae7598b6e002d76 javax_swing_border_CompoundBorder
// @dep_class 497b1fe8fe324c31 javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_CompoundBorder

#include "javax/swing/border/CompoundBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$method$_init$eb6e1e351633cb7f(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_CompoundBorder$vmethods	javax_swing_border_CompoundBorder;
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource;
    _jc_javax_swing_border_CompoundBorder$sub_refs	javax_swing_border_CompoundBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_CompoundBorder$sub_nonrefs	javax_swing_border_CompoundBorder;
    _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/BorderUIResource__24CompoundBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$CompoundBorderUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 1ae7598b6e002d76 javax_swing_border_CompoundBorder
// @dep_class 497b1fe8fe324c31 javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_CompoundBorder

#include "javax/swing/border/CompoundBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$method$_init$eb6e1e351633cb7f(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_CompoundBorder$vmethods	javax_swing_border_CompoundBorder;
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource;
    _jc_javax_swing_border_CompoundBorder$sub_refs	javax_swing_border_CompoundBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_CompoundBorder$sub_nonrefs	javax_swing_border_CompoundBorder;
    _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24CompoundBorderUIResource_H_ */
